@@ -15,7 +15,7 @@
 #  limitations under the License.
 
 import re
-from calculate.lib.format.procmail import procmail
+from .procmail import procmail
 
 
 class squid(procmail):
@@ -28,7 +28,7 @@ class squid(procmail):
     reSeparator = re.compile(" ")
 
     def prepare(self):
-        super(squid, self).prepare()
+        super().prepare()
         # Создаем поля-массивы
         self.docObj.postParserList()
         # Создаем поля разделенные массивы
