@@ -15,18 +15,18 @@
 #  limitations under the License.
 
 import sys
-from calculate.lib.utils.files import getProgPath, process
+from .files import getProgPath, process
 import re
 
 _ = lambda x: x
-from calculate.lib.cl_lang import setLocalTranslate
+from ..cl_lang import setLocalTranslate
 
 setLocalTranslate('cl_lib3', sys.modules[__name__])
 
 class SambaError(Exception):
     pass
 
-class Samba(object):
+class Samba():
 
     def nmblookup_ip_output(self, host):
         nmblookup = getProgPath("/usr/bin/nmblookup")
