@@ -244,7 +244,7 @@ class tableReport():
                     else:
                         align = "^"
                         offset = ""
-                    _print((u"%s{0:%s%d}" % (offset, align, width)).format(txt))
+                    _print(("%s{0:%s%d}" % (offset, align, width)).format(txt))
                     if i < last_col:
                         self.line_printer(char)
                 self.line_printer(char[:-self.colSpan + 1])
